@@ -39,11 +39,12 @@ try:
 except ModuleNotFoundError:
     print("Cython module not found. Use pyximport temporally")
     import pyximport
-    pyximport.install(language_level=3)  # '../elements/poly_calc.pyx',
-    import os
+    import os, sys
     pyxroot = os.path.dirname(os.path.abspath(__file__))
-    poly_calc = pyximport.load_module('poly_calc', pyxroot+'\\poly_calc.pyx', language_level=3)
-    # import poly_calc
+    sys.path.append(pyxroot)
+    pyximport.install(language_level=3)  # '../elements/poly_calc.pyx',
+    # poly_calc = pyximport.load_module('poly_calc', pyxroot+'\\poly_calc.pyx', language_level=3)
+    import poly_calc
 
 
 ################## 基础的一维曲线类(抽象类) 现在已经弃用！#####################
