@@ -1,5 +1,5 @@
 from spider.planner_zoo.BasePlanner import BasePlanner
 from spider.planner_zoo.LatticePlanner import LatticePlanner
-from spider.planner_zoo.MFRLPlanner import MFRLPlanner
+# from spider.planner_zoo.MFRLPlanner import MFRLPlanner
 from spider.planner_zoo.BezierPlanner import BezierPlanner
 
